@@ -6,7 +6,7 @@ use Storable qw(freeze thaw);
 use MIME::Base64;
 use Lemonldap::NG::Manager::Conf::Constants;
 
-our $VERSION = 0.13;
+our $VERSION = 0.14;
 
 sub prereq {
     my $self = shift;
@@ -106,6 +106,11 @@ sub load {
     return $row;
 }
 
+sub delete {
+    my ( $self, $cfgNum ) = @_;
+    $self->dbh->do( "DELETE from " . $self->{dbiTable} . " WHERE cfgNum=$cfgNum" );
+}
+
 sub logError {
     my $self = shift;
     print STDERR "Database error: " . $self->dbh->errstr . "\n";
